┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/search/searchcriteriondescription.h
diff options
context:
space:
mode:
authorPeter Penz <[email protected]>2009-11-13 22:48:07 +0000
committerPeter Penz <[email protected]>2009-11-13 22:48:07 +0000
commit3d7b54b21a47e98d1d02c7d21061a6bd43b8d1c7 (patch)
tree24a1db2c4b375d6f4d3ecc4ef2a4de6506374134 /src/search/searchcriteriondescription.h
parentbd30bb6ca98374b37db20d14a41542c21acdd5e0 (diff)
Implemented initialization of value-widgets. This allows e.g. to apply dates like "today", "last week", ... to the date-value-widgets just by specifying a search criterion.
svn path=/trunk/KDE/kdebase/apps/; revision=1048771
Diffstat (limited to 'src/search/searchcriteriondescription.h')
-rw-r--r--src/search/searchcriteriondescription.h12
1 files changed, 7 insertions, 5 deletions
diff --git a/src/search/searchcriteriondescription.h b/src/search/searchcriteriondescription.h
index 5da188633..98211793e 100644
--- a/src/search/searchcriteriondescription.h
+++ b/src/search/searchcriteriondescription.h
@@ -38,11 +38,13 @@ class SearchCriterionDescription
public:
struct Comparator
{
- Comparator(const QString& n, const QString& o = QString(), const QString& p = QString()) :
- name(n), operation(o), prefix(p) {}
- QString name; // user visible and translated name
- QString operation; // Nepomuk operation that represents the comparator
- QString prefix; // prefix like "+" or "-" that is part of the Nepomuk query
+ Comparator(const QString& n, const QString& o = QString(),
+ const QString& p = QString(), const QString& a = QString()) :
+ name(n), operation(o), prefix(p), autoValueType(a) {}
+ QString name; // user visible and translated name
+ QString operation; // Nepomuk operation that represents the comparator
+ QString prefix; // prefix like "+" or "-" that is part of the Nepomuk query
+ QString autoValueType; // type for an automatically calculated value of the value widget
};
SearchCriterionDescription(const QString& name,